#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

from zope.interface import implementer, provider
from zope.schema.fieldproperty import FieldProperty

from pyams_content import _
# import interfaces
from pyams_content.component.theme.interfaces import IThemesTarget
from pyams_content.features.checker.interfaces import IContentChecker, MISSING_VALUE
from pyams_content.features.review.interfaces import IReviewTarget
# import packages
from pyams_content.shared.common import WfSharedContent, register_content_type, SharedContent, WfSharedContentChecker, \
    IWfSharedContentFactory
from pyams_content.shared.logo.interfaces import IWfLogo, LOGO_CONTENT_TYPE, LOGO_CONTENT_NAME, ILogo, IWfLogoFactory
from pyams_file.property import FileProperty
from pyams_utils.adapter import adapter_config


@implementer(IWfLogo, IThemesTarget, IReviewTarget)
class WfLogo(WfSharedContent):
    """Logo persistent class"""

    content_type = LOGO_CONTENT_TYPE
    content_name = LOGO_CONTENT_NAME

    handle_content_url = False
    handle_header = False
    handle_description = False

    acronym = FieldProperty(IWfLogo['acronym'])
    url = FieldProperty(IWfLogo['url'])
    image = FileProperty(IWfLogo['image'])
    monochrome_image = FileProperty(IWfLogo['monochrome_image'])

register_content_type(WfLogo)


@provider(IWfLogoFactory)
@implementer(ILogo)
class Logo(SharedContent):
    """Workflow managed logo persistent class"""


@adapter_config(context=IWfLogoFactory, provides=IWfSharedContentFactory)
def logo_content_factory(context):
    return WfLogo


@adapter_config(name='properties', context=IWfLogo, provides=IContentChecker)
class WfLogoContentChecker(WfSharedContentChecker):
    """Logo content checker"""

    def inner_check(self, request):
        output = super(WfLogoContentChecker, self).inner_check(request)
        translate = request.localizer.translate
        if not (self.context.image and self.context.image.get_size()):
            output.append(translate(MISSING_VALUE).format(field=translate(IWfLogo['image'].title),
                                                          message=translate(_("no image defined"))))
        if not self.context.url:
            output.append(translate(MISSING_VALUE).format(field=translate(IWfLogo['url'].title),
                                                          message=translate(_("no URL defined"))))
        return output
